Crate pdao_colony_common

Crate pdao_colony_common 

Modules

colony_chain_encoder_dict
colony_chain_encoder_tuple
test_suite
A set of tests that can be used to test an implementation of trait ColonyChainExt.

Structs

Block
An abstract information about a block.
ColonyChainStub
ContractInfo
Information of a contract.

Enums

ContractType
A contract type.
Error
An error that can occur when interacting with the contract.

Traits

ColonyChain
An abstraction of a colony chain, which is viewed by the relayer and the explorer.
ColonyChainFallible
An abstraction of a colony chain, which is viewed by the relayer and the explorer.