Modules
- colony_
chain_ encoder_ dict - colony_
chain_ encoder_ tuple - test_
suite - A set of tests that can be used to test an implementation of
trait ColonyChainExt.
Structs
- Block
- An abstract information about a block.
- Colony
Chain Stub - Contract
Info - Information of a contract.
Enums
- Contract
Type - A contract type.
- Error
- An error that can occur when interacting with the contract.
Traits
- Colony
Chain - An abstraction of a colony chain, which is viewed by the relayer and the explorer.
- Colony
Chain Fallible - An abstraction of a colony chain, which is viewed by the relayer and the explorer.